@@ -372,26 +372,221 @@ class Score(Base):
 
 class Submission(Base):
     """
-    Модель "Отправленные работы"
+    Отправленные работы задании
     """
-
     __tablename__ = 'submissions'
 
+    # Идентификатор
     id = Column(Integer, primary_key=True)
+
+    # Неизвестное поле
+    body = Column(String)
+
+    # Неизвестное поле
+    url = Column(String(255))
+
+    # Неизвестное поле
+    attachment_id = Column(Integer)
+
+    # Оценка (В виде строки)
+    grade = Column(String(255))
+
+    # Оценка (В виде числа)
     score = Column(Float)
+
+    # Дата и время отправления
+    submitted_at = Column(DateTime)
+
+    # Задание
     assignment_id = Column(ForeignKey('assignments.id'))
     assignment = relationship('Assignment')
+
+    # Пользователь
     user_id = Column(ForeignKey('users.id'))
     user = relationship('User')
-    workflow_state = Column(String(255))
-    created_at = Column(DateTime)
-    updated_at = Column(DateTime)
+
+    # Тип отправки
+    # Способ по которому студент отправил свои работы
+    # Возможные значения:
+    # - online_quiz (Контрольная работа)
+    # - online_text_entry (Текстовая запись)
+    # - online_upload (Загрузки файла)
+    # - online_url (URL-адрес веб-сайта)
+    submission_type = Column(String(255))
+
+    @validates('submission_type')
+    def validate_submission_type(self, key, value):
+        """
+        Значением submission_type могут быть следующие значения:
+        - online_quiz (Контрольная работа)
+        - online_text_entry (Текстовая запись)
+        - online_upload (Загрузки файла)
+        - online_url (URL-адрес веб-сайта)
+        """
+        if value:
+            assert value in ['online_quiz', 'online_text_entry',
+                             'online_upload', 'online_url']
+
+        return value
+
+    # Статус
+    # Возможные значения:
+    # - deleted (Удален)
+    # - graded (Оценка поставлен)
+    # - pending_review (Требуется просмотр от преподавателя)
+    # - submitted (Студент отправил свою работу)
+    # - unsubmitted (Студент еще не отправил свою работу)
+    workflow_state = Column(String(255), default='unsubmitted')
+
+    @validates('workflow_state')
+    def validate_workflow_state(self, key, value):
+        """
+        Значением workflow_state могут быть следующие значения:
+        - deleted (Удален)
+        - graded (Оценка поставлен)
+        - pending_review (Требуется просмотр от преподавателя)
+        - submitted (Студент отправил свою работу)
+        - unsubmitted (Студент еще не отправил свою работу)
+        """
+        assert value in ['deleted', 'graded',
+                         'pending_review', 'submitted', 'unsubmitted']
+        return value
+
+    # Дата и время создания
+    # server_default - Автоматически устанавливает значение created_at на текущую дату и время при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    # onupdate - Автоматически изменяет updated_at на текущую дату и время
+    updated_at = Column(DateTime, onupdate=func.now())
+
+    # Неизвестное поле
+    group_id = Column(Integer)
+
+    # Неизвестное поле
+    attachment_ids = Column(String)
+
+    # Неизвестное поле
+    processed = Column(Boolean)
+
+    # Неизвестное поле
+    grade_matches_current_submission = Column(Boolean)
+
+    # Опубликованная оценка в виде строки (Неизвестное поле)
+    # В основном совпадает с полем score
+    published_score = Column(String(255))
+
+    # Опубликованная оценка в виде числа (Неизвестное поле)
+    # В основном совпадает с полем grade
+    published_grade = Column(Integer)
+
+    # Дата и время оценки преподавателем
+    graded_at = Column(DateTime)
+
+    # Неизвестное поле
+    student_entered_score = Column(String(255))
+
+    # Преподаватель который поставил оценку
+    # Почему-то есть значения с минусами (Неизвестное значение)
+    grader_id = Column(Integer)
+
+    # Неизвестное поле
+    media_comment_id = Column(String(255))
+
+    # Неизвестное поле
+    media_comment_type = Column(String(255))
+
+    # Идентификатор отправленной студентом контрольной работы
+    # Доступен, если задание представляет собой Контрольную работу
+    quiz_submission_id = Column(Integer)
+
+    # Неизвестное поле
+    submission_comments_count = Column(Integer)
+
+    # Текущая попытка
+    attempt = Column(Integer)
+
+    # Неизвестное поле
+    media_object_id = Column(Integer)
+
+    # Данные TurnItIn
+    # В основном не используется
+    turnitin_data = Column(String)
+
+    # Неизвестное поле
+    cached_due_date = Column(DateTime)
+
+    # Состояние - По уважительной причине
+    # Проставляется если студент не смог выполнить задание по уважительной причине
+    excused = Column(Boolean)
+
+    # Анонимно оценен
+    graded_anonymously = Column(Boolean)
+
+    # Состояние отправки задания
+    # Преподы могут поставить оценку и поставить состояние данной оценки
+    # Возможные значения:
+    # - late (Поздний) - Задание выполнили поздно
+    # - missing (Отсутствующий) - Задание не выполнили
+    # - none (Нет) - Отсутствует какое-либо состояние
+    late_policy_status = Column(String(255))
+
+    @validates('late_policy_status')
+    def validate_late_policy_status(self, key, value):
+        if value:
+            assert value in ['late', 'missing', 'none']
+
+        return value
+
+    # Неизвестное поле
+    points_deducted = Column(Integer)
+
+    # Неизвестное поле
+    grading_period_id = Column(Integer)
+
+    # Неизвестное поле
+    seconds_late_override = Column(Integer)
+
+    # LTI-идентификатор пользователя
+    lti_user_id = Column(String(255))
+
+    # Идентификатор анонимности
+    anonymous_id = Column(String(255))
+
+    # Дата и время последнего комментария
+    last_comment_at = Column(DateTime)
+
+    # Количество дополнительных попыток
+    extra_attempts = Column(Integer)
+
+    # Неизвестное поле
+    posted_at = Column(DateTime)
+
+    # Неизвестное поле
+    cached_quiz_lti = Column(Boolean)
+
+    # Неизвестное поле
+    cached_tardiness = Column(String(16))
+
+    # Курс
+    course_id = Column(ForeignKey('courses.id'))
+    course = relationship('Course')
+
+    # Корневая учетная запись
+    root_account_id = Column(ForeignKey('accounts.id'))
+    root_account = relationship('Account')
+
+    # Неизвестное поле
+    redo_request = Column(Boolean)
+
+    # Неизвестное поле
+    resource_link_lookup_uuid = Column(String(255))
 
     def __repr__(self):
-        return '<Submission {} (id={})>'.format(self, self.id)
+        return f'<Submission {self} (id={self.id} assignment_id={self.assignment_id} user_id={self.user_id})>'
 
     def __str__(self):
-        return str(self.score)
+        return f'{self.score}'
 
 
 class GradingStandard(Base):
