@@ -7,13 +7,13 @@ Base = declarative_base()
 
 
 def get_session(config):
-    engine = create_engine('postgresql+psycopg2://{}:{}@{}/canvas_production'.format(config.user, config.password, config.host))
+    engine = create_engine('postgresql+psycopg2://{}:{}@{}/canvas_production'.format(
+        config.user, config.password, config.host))
     conn = engine.connect()
 
-    Session = sessionmaker(bind=engine)
-    session = Session()
+    session_factory = sessionmaker(bind=engine)
+    return session_factory
 
-    return session
 
 def get_base():
-    return Base
\ No newline at end of file
+    return Base
